import { useState } from "react";
import { Flex, Input, List, ListItem, Box, InputRightElement, Icon, InputGroup } from "@chakra-ui/react";
import { FaSearch } from "react-icons/fa";
import { useGeneral } from "@/contexts/GeneralContext";

const SearchComponent = () => {
  const [searchTerm, setSearchTerm] = useState("");
  const [searchResults, setSearchResults] = useState<string[]>([]);
  const { isSearchListOpen, toggleSearchList } = useGeneral();

  // Function to handle search and update search results
  const handleSearch = (query:String) => {
    // Implement your search logic here (e.g., make an API call)
    // For simplicity, this example uses a static array as search results
    const results = ["Apple", "Banana", "Cherry", "Date"].filter((item) => item.toLowerCase().includes(query.toLowerCase()));

    setSearchResults(results);
    toggleSearchList(!!query);

  };

  const handleInputBlur = () => {
    // Close the search results list on input blur
    toggleSearchList(false);
  };

  return (
    <Box position="relative" display={{ base: "none", md: "flex" }} alignItems="center">
      <InputGroup>
        <Input
          w={{ lg: 650, sm: 0 }}
          bg="concrete.500"
          color="codGray.500"
          borderRadius="full"
          focusBorderColor="primary.300"
          placeholder="Search for Movies, TV shows, Themes & Cast"
          value={searchTerm}
          onChange={(e) => {
            setSearchTerm(e.target.value);
            handleSearch(e.target.value);
          }}
          size={"lg"}
          variant={"filled"}
          onBlur={handleInputBlur}
          onFocus={() => toggleSearchList(!!searchTerm)}
        />
        <InputRightElement h="100%" pr={2} pointerEvents="none">
          <Icon as={FaSearch} color="codGray.300" />
        </InputRightElement>
      </InputGroup>

      {isSearchListOpen && searchResults.length > 0 && (
        <Box position="absolute" mt={0.5} top="100%" left="0" zIndex="1" width="100%" bg="white" border="1px solid #ccc" borderRadius="md">
          <List onBlur={handleInputBlur}>
            {searchResults.map((result) => (
              <ListItem key={result} p={2} color="codGray.500">
                {result}
              </ListItem>
            ))}
          </List>
        </Box>
      )}
    </Box>
  );
};

export default SearchComponent;
